@@ -1,5 +1,6 @@
 import h5py
 import numpy as np
+import tensorflow as tf
 
 
 class HDF5Generator:
@@ -10,7 +11,7 @@ class HDF5Generator:
         f = self.data
 
         self.n_data = f["{}_data".format(self.prefix)].shape[0]
-        label_name= "{}_label".format(self.prefix)
+        label_name = "{}_label".format(self.prefix)
 
         self.n_class = len(np.unique(f[label_name][()]))
         hist = np.histogram(f[label_name][()], bins=self.n_class - 1)
@@ -25,3 +26,13 @@ class HDF5Generator:
         with h5py.File(self.path, 'r') as f:
             for d, l in zip(f["{}_data".format(self.prefix)], f["{}_label".format(self.prefix)]):
                 yield (d, l)
+
+    def get_dataset(self, input_shape=(300, 30), batch_size=32, shuffle=False, n_shuffle=10000):
+        d_set = tf.data.Dataset.from_generator(
+            self,
+            (tf.float32, tf.int8),
+            (tf.TensorShape(input_shape), tf.TensorShape([]))
+        )
+        d_set = d_set.shuffle(n_shuffle, reshuffle_each_iteration=True) if shuffle else d_set
+
+        return d_set.batch(batch_size).prefetch(tf.data.experimental.AUTOTUNE).repeat()
